@@ -223,6 +223,10 @@ class OAuth2Login(AsyncClient):
         """
         description:
             使用refresh_token刷新access_token（仅支持Google和GitLab）
+            
+            注意：GitLab 采用 token rotation（令牌轮换）机制，每次刷新时会返回新的 refresh_token，
+            旧的 refresh_token 会立即失效。必须保存新的 refresh_token 并替换旧的。
+            Google 也可能在某些情况下返回新的 refresh_token。
         parameters:
             refresh_token(str): OAuth refresh_token
         return:
@@ -816,6 +820,9 @@ class GitLabLogin(AsyncClient):
         """
         description:
             使用refresh_token刷新access_token
+            
+            注意：GitLab 采用 token rotation（令牌轮换）机制，每次刷新时会返回新的 refresh_token，
+            旧的 refresh_token 会立即失效。必须保存新的 refresh_token 并替换旧的。
         parameters:
             refresh_token(str): GitLab OAuth refresh_token
         return:
